#![warn(clippy::style, clippy::pedantic)]

mod db;
mod discord;
mod utils;

use std::error::Error;

use tracing::info;

#[tokio::main]
async fn main() -> Result<(), Box<dyn Error>> {
    println!("Setting logging up");
    utils::setup_logging();
    info!("Setting up color_eyre");
    color_eyre::install()?;
    info!("Reading from dotenv");
    let _ =
        dotenvy::dotenv().map_err(|_| info!("No .env file found, skipping"));
    info!("Launching bot");
    let bot = discord::make_bot();
    bot.run().await?;

    Ok(())
}
